@@ -40,10 +40,10 @@ if (defined($new_x)) {
 $SIG{'QUIT'} = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
 $SIG{'INT'}  = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
 
-my $screen_width  = $F->{'VXRES'};
-my $screen_height = $F->{'VYRES'};
-my $xm            = $F->{'VXRES'} / 1920;
-my $ym            = $F->{'VYRES'} / 1080;
+my $screen_width  = $F->{'XRES'};
+my $screen_height = $F->{'YRES'};
+my $xm            = $F->{'XRES'} / 1920;
+my $ym            = $F->{'YRES'} / 1080;
 my $XX            = $screen_width;
 my $YY            = $screen_height;
 my $center_x      = $XX / 2;
